@@ -21,7 +21,7 @@ def avgcyc(x,n,nanmask=False,stat = mean):
         else:
             masktemp = zeros_like(xtemp)
 
-            xout[ix] = stat(xtemp[where(isnan(masktemp == False))],axis=0)
+        xout[ix] = stat(xtemp[~isnan(masktemp)],axis=0)
     xout[n] = xout[0] 
     return xout
 
